@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+"""Classes that represent a ‘topocentric’ position on the Earth’s surface."""
 
 from numpy import arctan2, array, array2string, cos, exp, sin, sqrt
 from .constants import ANGVEL, DAY_S, RAD2DEG, T0, pi, tau
@@ -94,7 +95,7 @@ class GeographicPosition(ITRSPosition):
 
         """
         sprime = -47.0e-6 * (t.whole - T0 + t.tdb_fraction) / 36525.0
-        return (t.gast + self.longitude._hours + sprime / 54000.0) % 24.0
+        return (t.gast + self.longitude.hours + sprime / 54000.0) % 24.0
 
     def refract(self, altitude_degrees, temperature_C, pressure_mbar):
         """Predict how the atmosphere will refract a position.
@@ -144,6 +145,11 @@ class Geoid(object):
         f = 1.0 / inverse_flattening
         self._e2 = 2.0*f - f*f
 
+    @reify
+    def polar_radius(self):
+        """The Earth’s polar radius, as a :class:`~skyfield.units.Distance`."""
+        return Distance(self.radius.au * (1.0 - 1.0 / self.inverse_flattening))
+
     def latlon(self, latitude_degrees, longitude_degrees, elevation_m=0.0,
                cls=GeographicPosition):
         """Return a `GeographicPosition` for a given latitude and longitude.
